@@ -1,10 +1,6 @@
 from django import forms
-from django.conf import settings
 import logging
 
-from django_filters import ModelChoiceFilter
-from django_filters.fields import ModelChoiceField
-
 from nautobot.dcim.models import Device, Interface
 from nautobot.ipam.models import IPAddress, VLAN, VRF
 
@@ -43,15 +39,15 @@ class VRFPrimaryVLANForm(BootstrapMixin, forms.ModelForm):
 class VLANAddToVRFForm(BootstrapMixin, forms.ModelForm):
     vrf = DynamicModelChoiceField(
         queryset=VRF.objects.all(),
-        required=False,
+        required=True,
         label='VRF',
     )
 
     vlan = forms.ModelChoiceField(
         queryset=VLAN.objects.all(),
-        required=False,
+        required=True,
         disabled=True,
-        widget=forms.HiddenInput()
+        label="VLAN",
     )
 
     class Meta:
@@ -123,7 +119,6 @@ class JoinEthernetSegmentForm(BootstrapMixin, forms.ModelForm):
 class EthernetSegmentForm(BootstrapMixin, forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
-
         if "initial" in kwargs:
             kwargs['initial']['segment_id'] = get_unused_es_number()
 
