@@ -1,19 +1,16 @@
 import django_tables2 as tables
 
-from nautobot.utilities.tables import BaseTable, ButtonsColumn
+from nautobot.utilities.tables import BaseTable
 from .models import (
     EthernetSegment,
     EthernetSegmentMembership
 )
 
-
 ACTIONS = """
 <a href="{% url "plugins:nautobot_evpn:es-delete" pk=record.pk %}" class="btn btn-danger"> <i class="mdi mdi-trash-can-outline"></i></a>
 """
 
 
-
-
 class EthernetSegmentTable(BaseTable):
     actions = tables.TemplateColumn(
         verbose_name='Actions',
