@@ -1,8 +1,8 @@
 import logging
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
-from django.contrib.auth.mixins import PermissionRequiredMixin, LoginRequiredMixin
-from django.shortcuts import get_object_or_404, redirect, render, reverse
+from django.contrib.auth.mixins import PermissionRequiredMixin
+from django.shortcuts import get_object_or_404, reverse
 from django.utils.decorators import method_decorator
 from django.views.generic import View
 from django.views.generic.edit import CreateView
@@ -76,13 +76,14 @@ class AddVRFView(PermissionRequiredMixin, CreateWithReturnView):
     model = VLANVRFList
     form_class = VLANAddToVRFForm
     permission_required = 'ipam.change_vlan'
+    template_name = "nautobot_evpn/vlanvrf_form.html"
 
     def get_success_url(self):
         pk = self.request.resolver_match.kwargs['pk']
         return reverse('ipam:vlan', kwargs={'pk': pk})
 
     def get_initial(self):
-        vlan = VLAN.objects.get(pk=self.request.resolver_match.kwargs['pk'])
+        vlan = VLAN.objects.get(pk=self.kwargs['pk'])
         return {'vlan': vlan}
 
 
@@ -137,7 +138,6 @@ class EthernetSegmentListView(PermissionRequiredMixin, ObjectListView):
 
 
 class ExtendedInterfaceTable(InterfaceTable):
-
     class Meta(InterfaceTable.Meta):
         pass
 
@@ -161,7 +161,6 @@ class ExtendedInterfaceTable(InterfaceTable):
         return c if physical_interface else None
 
 
-
 class EthernetSegmentView(ObjectView):
     queryset = EthernetSegment.objects.all()
 
